## Usage

Beancount2ledger takes a file argument, loads the file into beancount data structures, and converts the data to ledger output.

You can use the `--format` (`-f`) option to toggle between `ledger` and `hledger` output.

You can use the `--config` (`-c`) option to specify a configuration file.

The option `--version` (`-V`) shows the version of beancount2ledger installed on your system.

